==> elasticloadbalancingv2-0.26.0-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/CfnLoadBalancer.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * @cloudformationResource AWS::ElasticLoadBalancingV2::LoadBalancer
 * A CloudFormation `AWS::ElasticLoadBalancingV2::LoadBalancer`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-loadbalancer.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:59:38.976Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.CfnLoadBalancer")
public class CfnLoadBalancer extends software.amazon.awscdk.CfnResource {
    protected CfnLoadBalancer(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancer.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::ElasticLoadBalancingV2::LoadBalancer`.
     * @param scope - scope in which this resource is defined
     * @param id - scoped id of the resource
     * @param props - resource properties
     */
    public CfnLoadBalancer(final software.amazon.awscdk.Construct scope, final java.lang.String id, @javax.annotation.Nullable final software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(props)).toArray());
    }
    /**
     * Create a new `AWS::ElasticLoadBalancingV2::LoadBalancer`.
     * @param scope - scope in which this resource is defined
     * @param id - scoped id of the resource
     */
    public CfnLoadBalancer(final software.amazon.awscdk.Construct scope, final java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getLoadBalancerArn() {
        return this.jsiiGet("loadBalancerArn", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute CanonicalHostedZoneID
     */
    public java.lang.String getLoadBalancerCanonicalHostedZoneId() {
        return this.jsiiGet("loadBalancerCanonicalHostedZoneId", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute DNSName
     */
    public java.lang.String getLoadBalancerDnsName() {
        return this.jsiiGet("loadBalancerDnsName", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute LoadBalancerFullName
     */
    public java.lang.String getLoadBalancerFullName() {
        return this.jsiiGet("loadBalancerFullName", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute LoadBalancerName
     */
    public java.lang.String getLoadBalancerName() {
        return this.jsiiGet("loadBalancerName", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute SecurityGroups
     */
    public java.util.List<java.lang.String> getLoadBalancerSecurityGroups() {
        return this.jsiiGet("loadBalancerSecurityGroups", java.util.List.class);
    }

    public software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancerProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancerProps.class);
    }

    /**
     * The `TagManager` handles setting, removing and formatting tags
     * 
     * Tags should be managed either passing them as properties during
     * initiation or by calling methods on this object. If both techniques are
     * used only the tags from the TagManager will be used. `Tag` (aspect)
     * will use the manager.
     */
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html
     */
    public static interface LoadBalancerAttributeProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * `CfnLoadBalancer.LoadBalancerAttributeProperty.Key`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-key
         */
        java.lang.String getKey();
        /**
         * `CfnLoadBalancer.LoadBalancerAttributeProperty.Key`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-key
         */
        void setKey(final java.lang.String value);
        /**
         * `CfnLoadBalancer.LoadBalancerAttributeProperty.Value`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-value
         */
        java.lang.String getValue();
        /**
         * `CfnLoadBalancer.LoadBalancerAttributeProperty.Value`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-value
         */
        void setValue(final java.lang.String value);

        /**
         * @return a {@link Builder} of {@link LoadBalancerAttributeProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link LoadBalancerAttributeProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.String _key;
            @javax.annotation.Nullable
            private java.lang.String _value;

            /**
             * Sets the value of Key
             * @param value `CfnLoadBalancer.LoadBalancerAttributeProperty.Key`
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final java.lang.String value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value `CfnLoadBalancer.LoadBalancerAttributeProperty.Value`
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final java.lang.String value) {
                this._value = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link LoadBalancerAttributeProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public LoadBalancerAttributeProperty build() {
                return new LoadBalancerAttributeProperty() {
                    @javax.annotation.Nullable
                    private java.lang.String $key = _key;
                    @javax.annotation.Nullable
                    private java.lang.String $value = _value;

                    @Override
                    public java.lang.String getKey() {
                        return this.$key;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                        this.$key = value;
                    }

                    @Override
                    public java.lang.String getValue() {
                        return this.$value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                        this.$value = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancer.LoadBalancerAttributeProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * `CfnLoadBalancer.LoadBalancerAttributeProperty.Key`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-key
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getKey() {
                return this.jsiiGet("key", java.lang.String.class);
            }

            /**
             * `CfnLoadBalancer.LoadBalancerAttributeProperty.Key`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("key", value);
            }

            /**
             * `CfnLoadBalancer.LoadBalancerAttributeProperty.Value`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-value
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getValue() {
                return this.jsiiGet("value", java.lang.String.class);
            }

            /**
             * `CfnLoadBalancer.LoadBalancerAttributeProperty.Value`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("value", value);
            }
        }
    }
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html
     */
    public static interface SubnetMappingProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * `CfnLoadBalancer.SubnetMappingProperty.AllocationId`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-allocationid
         */
        java.lang.String getAllocationId();
        /**
         * `CfnLoadBalancer.SubnetMappingProperty.AllocationId`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-allocationid
         */
        void setAllocationId(final java.lang.String value);
        /**
         * `CfnLoadBalancer.SubnetMappingProperty.SubnetId`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-subnetid
         */
        java.lang.String getSubnetId();
        /**
         * `CfnLoadBalancer.SubnetMappingProperty.SubnetId`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-subnetid
         */
        void setSubnetId(final java.lang.String value);

        /**
         * @return a {@link Builder} of {@link SubnetMappingProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link SubnetMappingProperty}
         */
        final class Builder {
            private java.lang.String _allocationId;
            private java.lang.String _subnetId;

            /**
             * Sets the value of AllocationId
             * @param value `CfnLoadBalancer.SubnetMappingProperty.AllocationId`
             * @return {@code this}
             */
            public Builder withAllocationId(final java.lang.String value) {
                this._allocationId = java.util.Objects.requireNonNull(value, "allocationId is required");
                return this;
            }
            /**
             * Sets the value of SubnetId
             * @param value `CfnLoadBalancer.SubnetMappingProperty.SubnetId`
             * @return {@code this}
             */
            public Builder withSubnetId(final java.lang.String value) {
                this._subnetId = java.util.Objects.requireNonNull(value, "subnetId is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link SubnetMappingProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public SubnetMappingProperty build() {
                return new SubnetMappingProperty() {
                    private java.lang.String $allocationId = java.util.Objects.requireNonNull(_allocationId, "allocationId is required");
                    private java.lang.String $subnetId = java.util.Objects.requireNonNull(_subnetId, "subnetId is required");

                    @Override
                    public java.lang.String getAllocationId() {
                        return this.$allocationId;
                    }

                    @Override
                    public void setAllocationId(final java.lang.String value) {
                        this.$allocationId = java.util.Objects.requireNonNull(value, "allocationId is required");
                    }

                    @Override
                    public java.lang.String getSubnetId() {
                        return this.$subnetId;
                    }

                    @Override
                    public void setSubnetId(final java.lang.String value) {
                        this.$subnetId = java.util.Objects.requireNonNull(value, "subnetId is required");
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancer.SubnetMappingProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * `CfnLoadBalancer.SubnetMappingProperty.AllocationId`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-allocationid
             */
            @Override
            public java.lang.String getAllocationId() {
                return this.jsiiGet("allocationId", java.lang.String.class);
            }

            /**
             * `CfnLoadBalancer.SubnetMappingProperty.AllocationId`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-allocationid
             */
            @Override
            public void setAllocationId(final java.lang.String value) {
                this.jsiiSet("allocationId", java.util.Objects.requireNonNull(value, "allocationId is required"));
            }

            /**
             * `CfnLoadBalancer.SubnetMappingProperty.SubnetId`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-subnetid
             */
            @Override
            public java.lang.String getSubnetId() {
                return this.jsiiGet("subnetId", java.lang.String.class);
            }

            /**
             * `CfnLoadBalancer.SubnetMappingProperty.SubnetId`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-subnetid
             */
            @Override
            public void setSubnetId(final java.lang.String value) {
                this.jsiiSet("subnetId", java.util.Objects.requireNonNull(value, "subnetId is required"));
            }
        }
    }
}

==> elasticloadbalancingv2-0.27.0-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/CfnLoadBalancer.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * @cloudformationResource AWS::ElasticLoadBalancingV2::LoadBalancer
 * A CloudFormation `AWS::ElasticLoadBalancingV2::LoadBalancer`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-loadbalancer.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:37:24.834Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.CfnLoadBalancer")
public class CfnLoadBalancer extends software.amazon.awscdk.CfnResource {
    protected CfnLoadBalancer(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancer.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::ElasticLoadBalancingV2::LoadBalancer`.
     * @param scope - scope in which this resource is defined
     * @param id - scoped id of the resource
     * @param props - resource properties
     */
    public CfnLoadBalancer(final software.amazon.awscdk.Construct scope, final java.lang.String id, @javax.annotation.Nullable final software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(props)).toArray());
    }
    /**
     * Create a new `AWS::ElasticLoadBalancingV2::LoadBalancer`.
     * @param scope - scope in which this resource is defined
     * @param id - scoped id of the resource
     */
    public CfnLoadBalancer(final software.amazon.awscdk.Construct scope, final java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getLoadBalancerArn() {
        return this.jsiiGet("loadBalancerArn", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute CanonicalHostedZoneID
     */
    public java.lang.String getLoadBalancerCanonicalHostedZoneId() {
        return this.jsiiGet("loadBalancerCanonicalHostedZoneId", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute DNSName
     */
    public java.lang.String getLoadBalancerDnsName() {
        return this.jsiiGet("loadBalancerDnsName", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute LoadBalancerFullName
     */
    public java.lang.String getLoadBalancerFullName() {
        return this.jsiiGet("loadBalancerFullName", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute LoadBalancerName
     */
    public java.lang.String getLoadBalancerName() {
        return this.jsiiGet("loadBalancerName", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute SecurityGroups
     */
    public java.util.List<java.lang.String> getLoadBalancerSecurityGroups() {
        return this.jsiiGet("loadBalancerSecurityGroups", java.util.List.class);
    }

    public software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancerProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancerProps.class);
    }

    /**
     * The `TagManager` handles setting, removing and formatting tags
     * 
     * Tags should be managed either passing them as properties during
     * initiation or by calling methods on this object. If both techniques are
     * used only the tags from the TagManager will be used. `Tag` (aspect)
     * will use the manager.
     */
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html
     */
    public static interface LoadBalancerAttributeProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * `CfnLoadBalancer.LoadBalancerAttributeProperty.Key`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-key
         */
        java.lang.String getKey();
        /**
         * `CfnLoadBalancer.LoadBalancerAttributeProperty.Value`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-value
         */
        java.lang.String getValue();

        /**
         * @return a {@link Builder} of {@link LoadBalancerAttributeProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link LoadBalancerAttributeProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.String _key;
            @javax.annotation.Nullable
            private java.lang.String _value;

            /**
             * Sets the value of Key
             * @param value `CfnLoadBalancer.LoadBalancerAttributeProperty.Key`
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final java.lang.String value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value `CfnLoadBalancer.LoadBalancerAttributeProperty.Value`
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final java.lang.String value) {
                this._value = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link LoadBalancerAttributeProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public LoadBalancerAttributeProperty build() {
                return new LoadBalancerAttributeProperty() {
                    @javax.annotation.Nullable
                    private final java.lang.String $key = _key;
                    @javax.annotation.Nullable
                    private final java.lang.String $value = _value;

                    @Override
                    public java.lang.String getKey() {
                        return this.$key;
                    }

                    @Override
                    public java.lang.String getValue() {
                        return this.$value;
                    }

                    public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                        com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                        com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                        obj.set("key", om.valueToTree(this.getKey()));
                        obj.set("value", om.valueToTree(this.getValue()));
                        return obj;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancer.LoadBalancerAttributeProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * `CfnLoadBalancer.LoadBalancerAttributeProperty.Key`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-key
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getKey() {
                return this.jsiiGet("key", java.lang.String.class);
            }

            /**
             * `CfnLoadBalancer.LoadBalancerAttributeProperty.Value`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattributes.html#cfn-elasticloadbalancingv2-loadbalancer-loadbalancerattributes-value
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getValue() {
                return this.jsiiGet("value", java.lang.String.class);
            }
        }
    }
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html
     */
    public static interface SubnetMappingProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * `CfnLoadBalancer.SubnetMappingProperty.AllocationId`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-allocationid
         */
        java.lang.String getAllocationId();
        /**
         * `CfnLoadBalancer.SubnetMappingProperty.SubnetId`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-subnetid
         */
        java.lang.String getSubnetId();

        /**
         * @return a {@link Builder} of {@link SubnetMappingProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link SubnetMappingProperty}
         */
        final class Builder {
            private java.lang.String _allocationId;
            private java.lang.String _subnetId;

            /**
             * Sets the value of AllocationId
             * @param value `CfnLoadBalancer.SubnetMappingProperty.AllocationId`
             * @return {@code this}
             */
            public Builder withAllocationId(final java.lang.String value) {
                this._allocationId = java.util.Objects.requireNonNull(value, "allocationId is required");
                return this;
            }
            /**
             * Sets the value of SubnetId
             * @param value `CfnLoadBalancer.SubnetMappingProperty.SubnetId`
             * @return {@code this}
             */
            public Builder withSubnetId(final java.lang.String value) {
                this._subnetId = java.util.Objects.requireNonNull(value, "subnetId is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link SubnetMappingProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public SubnetMappingProperty build() {
                return new SubnetMappingProperty() {
                    private final java.lang.String $allocationId = java.util.Objects.requireNonNull(_allocationId, "allocationId is required");
                    private final java.lang.String $subnetId = java.util.Objects.requireNonNull(_subnetId, "subnetId is required");

                    @Override
                    public java.lang.String getAllocationId() {
                        return this.$allocationId;
                    }

                    @Override
                    public java.lang.String getSubnetId() {
                        return this.$subnetId;
                    }

                    public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                        com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                        com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                        obj.set("allocationId", om.valueToTree(this.getAllocationId()));
                        obj.set("subnetId", om.valueToTree(this.getSubnetId()));
                        return obj;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.CfnLoadBalancer.SubnetMappingProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * `CfnLoadBalancer.SubnetMappingProperty.AllocationId`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-allocationid
             */
            @Override
            public java.lang.String getAllocationId() {
                return this.jsiiGet("allocationId", java.lang.String.class);
            }

            /**
             * `CfnLoadBalancer.SubnetMappingProperty.SubnetId`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html#cfn-elasticloadbalancingv2-loadbalancer-subnetmapping-subnetid
             */
            @Override
            public java.lang.String getSubnetId() {
                return this.jsiiGet("subnetId", java.lang.String.class);
            }
        }
    }
}
